@@ -4,7 +4,6 @@ import (
 	"crypto/tls"
 	"encoding/json"
 	"fmt"
-	"io/ioutil"
 	"net/http"
 	"net/http/httptest"
 	"net/url"
@@ -42,9 +41,7 @@ var (
 )
 
 func TestLogRotation(t *testing.T) {
-	tempDir := createTempDir(t, "traefik_")
-
-	fileName := filepath.Join(tempDir, "traefik.log")
+	fileName := filepath.Join(t.TempDir(), "traefik.log")
 	rotatedFileName := fileName + ".rotated"
 
 	config := &types.AccessLog{FilePath: fileName, Format: CommonFormat}
@@ -100,7 +97,7 @@ func TestLogRotation(t *testing.T) {
 
 func lineCount(t *testing.T, fileName string) int {
 	t.Helper()
-	fileContents, err := ioutil.ReadFile(fileName)
+	fileContents, err := os.ReadFile(fileName)
 	if err != nil {
 		t.Fatalf("Error reading from file %s: %s", fileName, err)
 	}
@@ -117,9 +114,7 @@ func lineCount(t *testing.T, fileName string) int {
 }
 
 func TestLoggerHeaderFields(t *testing.T) {
-	tmpDir := createTempDir(t, CommonFormat)
-
-	expectedValue := "expectedValue"
+	expectedValues := []string{"AAA", "BBB"}
 
 	testCases := []struct {
 		desc            string
@@ -172,7 +167,7 @@ func TestLoggerHeaderFields(t *testing.T) {
 	for _, test := range testCases {
 		test := test
 		t.Run(test.desc, func(t *testing.T) {
-			logFile, err := ioutil.TempFile(tmpDir, "*.log")
+			logFile, err := os.CreateTemp(t.TempDir(), "*.log")
 			require.NoError(t, err)
 
 			config := &types.AccessLog{
@@ -196,32 +191,33 @@ func TestLoggerHeaderFields(t *testing.T) {
 					Path: testPath,
 				},
 			}
-			req.Header.Set(test.header, expectedValue)
+
+			for _, s := range expectedValues {
+				req.Header.Add(test.header, s)
+			}
 
 			logger.ServeHTTP(httptest.NewRecorder(), req, http.HandlerFunc(func(writer http.ResponseWriter, r *http.Request) {
 				writer.WriteHeader(http.StatusOK)
 			}))
 
-			logData, err := ioutil.ReadFile(logFile.Name())
+			logData, err := os.ReadFile(logFile.Name())
 			require.NoError(t, err)
 
 			if test.expected == types.AccessLogDrop {
-				assert.NotContains(t, string(logData), expectedValue)
+				assert.NotContains(t, string(logData), strings.Join(expectedValues, ","))
 			} else {
-				assert.Contains(t, string(logData), expectedValue)
+				assert.Contains(t, string(logData), strings.Join(expectedValues, ","))
 			}
 		})
 	}
 }
 
 func TestLoggerCLF(t *testing.T) {
-	tmpDir := createTempDir(t, CommonFormat)
-
-	logFilePath := filepath.Join(tmpDir, logFileNameSuffix)
+	logFilePath := filepath.Join(t.TempDir(), logFileNameSuffix)
 	config := &types.AccessLog{FilePath: logFilePath, Format: CommonFormat}
 	doLogging(t, config)
 
-	logData, err := ioutil.ReadFile(logFilePath)
+	logData, err := os.ReadFile(logFilePath)
 	require.NoError(t, err)
 
 	expectedLog := ` TestHost - TestUser [13/Apr/2016:07:14:19 -0700] "POST testpath HTTP/0.0" 123 12 "testReferer" "testUserAgent" 1 "testRouter" "http://127.0.0.1/testService" 1ms`
@@ -229,13 +225,11 @@ func TestLoggerCLF(t *testing.T) {
 }
 
 func TestAsyncLoggerCLF(t *testing.T) {
-	tmpDir := createTempDir(t, CommonFormat)
-
-	logFilePath := filepath.Join(tmpDir, logFileNameSuffix)
+	logFilePath := filepath.Join(t.TempDir(), logFileNameSuffix)
 	config := &types.AccessLog{FilePath: logFilePath, Format: CommonFormat, BufferingSize: 1024}
 	doLogging(t, config)
 
-	logData, err := ioutil.ReadFile(logFilePath)
+	logData, err := os.ReadFile(logFilePath)
 	require.NoError(t, err)
 
 	expectedLog := ` TestHost - TestUser [13/Apr/2016:07:14:19 -0700] "POST testpath HTTP/0.0" 123 12 "testReferer" "testUserAgent" 1 "testRouter" "http://127.0.0.1/testService" 1ms`
@@ -355,9 +349,11 @@ func TestLoggerJSON(t *testing.T) {
 				Duration:                  assertFloat64NotZero(),
 				Overhead:                  assertFloat64NotZero(),
 				RetryAttempts:             assertFloat64(float64(testRetryAttempts)),
+				TLSVersion:                assertString("1.3"),
+				TLSCipher:                 assertString("TLS_ECDHE_ECDSA_WITH_AES_128_GCM_SHA256"),
 				"time":                    assertNotEmpty(),
-				"StartLocal":              assertNotEmpty(),
-				"StartUTC":                assertNotEmpty(),
+				StartLocal:                assertNotEmpty(),
+				StartUTC:                  assertNotEmpty(),
 			},
 		},
 		{
@@ -450,9 +446,7 @@ func TestLoggerJSON(t *testing.T) {
 		t.Run(test.desc, func(t *testing.T) {
 			t.Parallel()
 
-			tmpDir := createTempDir(t, JSONFormat)
-
-			logFilePath := filepath.Join(tmpDir, logFileNameSuffix)
+			logFilePath := filepath.Join(t.TempDir(), logFileNameSuffix)
 
 			test.config.FilePath = logFilePath
 			if test.tls {
@@ -461,7 +455,7 @@ func TestLoggerJSON(t *testing.T) {
 				doLogging(t, test.config)
 			}
 
-			logData, err := ioutil.ReadFile(logFilePath)
+			logData, err := os.ReadFile(logFilePath)
 			require.NoError(t, err)
 
 			jsonData := make(map[string]interface{})
@@ -675,7 +669,7 @@ func TestNewLogHandlerOutputStdout(t *testing.T) {
 
 			doLogging(t, test.config)
 
-			written, err := ioutil.ReadFile(file.Name())
+			written, err := os.ReadFile(file.Name())
 			require.NoError(t, err, "unable to read captured stdout from file")
 			assertValidLogData(t, test.expectedLog, written)
 		})
@@ -683,6 +677,8 @@ func TestNewLogHandlerOutputStdout(t *testing.T) {
 }
 
 func assertValidLogData(t *testing.T, expected string, logData []byte) {
+	t.Helper()
+
 	if len(expected) == 0 {
 		assert.Zero(t, len(logData))
 		t.Log(string(logData))
@@ -709,14 +705,16 @@ func assertValidLogData(t *testing.T, expected string, logData []byte) {
 	assert.Equal(t, resultExpected[OriginContentSize], result[OriginContentSize], formatErrMessage)
 	assert.Equal(t, resultExpected[RequestRefererHeader], result[RequestRefererHeader], formatErrMessage)
 	assert.Equal(t, resultExpected[RequestUserAgentHeader], result[RequestUserAgentHeader], formatErrMessage)
-	assert.Regexp(t, regexp.MustCompile("[0-9]*"), result[RequestCount], formatErrMessage)
+	assert.Regexp(t, regexp.MustCompile(`\d*`), result[RequestCount], formatErrMessage)
 	assert.Equal(t, resultExpected[RouterName], result[RouterName], formatErrMessage)
 	assert.Equal(t, resultExpected[ServiceURL], result[ServiceURL], formatErrMessage)
-	assert.Regexp(t, regexp.MustCompile("[0-9]*ms"), result[Duration], formatErrMessage)
+	assert.Regexp(t, regexp.MustCompile(`\d*ms`), result[Duration], formatErrMessage)
 }
 
 func captureStdout(t *testing.T) (out *os.File, restoreStdout func()) {
-	file, err := ioutil.TempFile("", "testlogger")
+	t.Helper()
+
+	file, err := os.CreateTemp("", "testlogger")
 	require.NoError(t, err, "failed to create temp file")
 
 	original := os.Stdout
@@ -730,16 +728,9 @@ func captureStdout(t *testing.T) (out *os.File, restoreStdout func()) {
 	return file, restoreStdout
 }
 
-func createTempDir(t *testing.T, prefix string) string {
-	tmpDir, err := ioutil.TempDir("", prefix)
-	require.NoError(t, err, "failed to create temp dir")
-
-	t.Cleanup(func() { _ = os.RemoveAll(tmpDir) })
-
-	return tmpDir
-}
-
 func doLoggingTLSOpt(t *testing.T, config *types.AccessLog, enableTLS bool) {
+	t.Helper()
+
 	logger, err := NewHandler(config)
 	require.NoError(t, err)
 	defer logger.Close()
@@ -764,17 +755,24 @@ func doLoggingTLSOpt(t *testing.T, config *types.AccessLog, enableTLS bool) {
 		},
 	}
 	if enableTLS {
-		req.TLS = &tls.ConnectionState{}
+		req.TLS = &tls.ConnectionState{
+			Version:     tls.VersionTLS13,
+			CipherSuite: tls.TLS_ECDHE_ECDSA_WITH_AES_128_GCM_SHA256,
+		}
 	}
 
 	logger.ServeHTTP(httptest.NewRecorder(), req, http.HandlerFunc(logWriterTestHandlerFunc))
 }
 
 func doLoggingTLS(t *testing.T, config *types.AccessLog) {
+	t.Helper()
+
 	doLoggingTLSOpt(t, config, true)
 }
 
 func doLogging(t *testing.T, config *types.AccessLog) {
+	t.Helper()
+
 	doLoggingTLSOpt(t, config, false)
 }
 
